The highest tagged major version is
v2.
package
Version:
v0.0.4
Opens a new window with list of versions in this module.
Published: Apr 7, 2021
License: MIT
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Page struct {
Orders []Order
Offset int
Size int
}
order by age desc limit 2,1
type Q interface {
Sql() string
And(q Q) Q
Or(q Q) Q
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.